/* eslint-disable @typescript-eslint/explicit-member-accessibility */

import {EventEmitter2} from 'eventemitter2';
import * as Immutable from 'immutable';
import {Observable} from 'rxjs';

import {ConferenceInvite} from '../conferences/ConferenceInvite';
import {LocalMediaHandler} from '../media/LocalMediaHandler';
import {ManagedStream} from '../media/ManagedStream';
import {ContextInfo, MediaTypes} from '../types';

import {ConferenceStatus} from './ConferenceStatus';
import {Invitation} from './Invitation';

export interface InviteParticipant {
	to: string;
	inviteId: string;
}

export class Conference {
	emitter: EventEmitter2;

	static create(
		room: any,
		mediaConstraints: MediaStreamConstraints
	): Promise<Conference>;

	/**
	 * Use to keep the number of invitations sent in this conference.
	 */
	invitationCount: number;

	/**
	 * Check if conference is on hold state.
	 */
	isOnHold: boolean;

	/**
	 * Allows access to local streams and actions related to changing what local media is shared
	 */
	getLocalMediaHandler(): LocalMediaHandler;

	/**
	 * Invites an agent to a conference.
	 */
	callAgent(
		mediaTypes?: MediaTypes,
		contextInfo?: ContextInfo,
		token?: string,
	): Promise<any>;

	/**
	 * Invites an agent with a particular skill to a conference.
	 */
	callSkilledAgent(
		mediaTypes?: MediaTypes,
		skill?: string,
		contextInfo?: ContextInfo,
		token?: string,
	): Promise<any>;

	/**
	 * Invites the voicemail to a conference.
	 */
	callVoiceMail(mediaTypes?: MediaTypes): Promise<any>;

	/**
	 * Expels a participant from this conference.
	 */
	expelParticipant(participant: string, session?: string): Promise<any>;

	/**
	 * Expels a list of participants from this conference.
	 */
	expelParticipants(participants: string[]): Promise<any>;

	/**
	 * Returns the current participant count.
	 */
	getCurrentParticipants(): number;

	/**
	 * Returns if the conference is recorded
	 */
	isRecorded(): boolean;

	/**
	 * Returns the ID of the conference.
	 */
	getId(): string;

	/**
	 * Returns the timestamp when the join to this conference was completed
	 */
	getJoinTimestamp(): number;

	/**
	 * Returns the invitation to the conference if the participant was invited.
	 */
	getInvite(): ConferenceInvite;

	/**
	 * Returns a set of outgoing invitations.
	 */
	getOutgoingInvitations(): Immutable.Set<object>;

	/**
	 * Returns a set of strings containing the gateway username of every remote
	 * participant.
	 */
	getRemoteGatewayUsernames(): Immutable.Set<string>;

	/**
	 * Returns a Map containing a list of ManagedStreams per participant
	 * (gateway user name).
	 */
	getRemoteStreams(): Immutable.Map<string, ManagedStream[]>;

	getRemoteParticipants(): Immutable.Map<string, 'HOLD' | 'IN_CALL'>;

	/**
	 * Returns the current status of the conference.
	 */
	getStatus(): ConferenceStatus;
	getStatus$(): Observable<ConferenceStatus>;

	/**
	 * Returns a boolean value indicating if at least one of the remote
	 * conference participants has a video track.
	 */
	hasRemoteVideo(): boolean;

	/**
	 * Enable/disable local hold Local hold mutes conference audio streams
	 * (local and remote) and stops receiving/sending video (if any).
	 */
	hold(): Promise<any>;

	/**
	 * Republishes all previously published media, subscribes to previously subscribed media and
	 * notifies new status to other participants
	 */
	unhold(): Promise<void>;

	/**
	 * Invites a new participant to this conference.
	 */
	inviteParticipant(participant: string, mediaTypes?: MediaTypes, context?: Record<string, string>): Promise<any>;

	/**
	 * Invites many participants to a conference.
	 */
	inviteMany(participants: string[], mediaTypes?: MediaTypes, context?: Record<string, string>): Promise<any>;

	/**
	 * Invites a list of new participant to this conference.
	 */
	inviteParticipants(participants: string[]): Promise<any>;

	/**
	 * Check if a conference is being transfering.
	 */
	isBeingTransfered(): boolean;

	isRecovered(): boolean;

	/**
	 * Connects to the conference.
	 */
	join(): Promise<any>;

	/**
	 * Leaves the conference.
	 */
	leave(errorCode?: number): any;

	/**
	 * Create an unattendedCallTransfer towards a user in the system.
	 */
	unattendedCallTransfer(participant: string, mediaConstraints?: MediaStreamConstraints): Promise<any>;

	cancelInvitation(invitation: Invitation, session?: string): void;
}
