import EventEmitter from 'eventemitter3';
import { Observable } from 'rxjs';
import { MediaTypes } from '../types';
import { ManagedStream } from './ManagedStream';
declare type UpdateMedia = (audio: MediaStreamConstraints['audio'], video: MediaStreamConstraints['video'], screen: boolean) => Promise<void>;
interface Events {
    videoStream: [];
    '*': [];
}
/**
 * Provides access to methods for managing actions related to local media. Instances of this class
 * are obtained calling {@link Conference#getLocalMediaHandler}
 *
 * ## Events
 *
 * - `videoStream` - Emitted every time videoStream changes.
 * - `*` - Emitted every time a change that can affect to any property happens.
 */
export declare class LocalMediaHandler {
    readonly emitter: EventEmitter<Events>;
    /** The list of available audio input devices */
    readonly audioInputDevices$: Observable<MediaDeviceInfo[]>;
    /** The list of available video input devices */
    readonly audioOutputDevices$: Observable<MediaDeviceInfo[]>;
    /** The list of available audio output devices */
    readonly videoInputDevices$: Observable<MediaDeviceInfo[]>;
    /** The MediaDeviceInfo of the active audio device */
    readonly activeAudioInputDevice$: Observable<MediaDeviceInfo | undefined>;
    /** The MediaDeviceInfo of the active video device */
    readonly activeVideoInputDevice$: Observable<MediaDeviceInfo | undefined>;
    /** Indicates if video can be enabled or disabled */
    canToggleVideo$: Observable<boolean>;
    /** Indicates if it is possible to change to a different camera */
    canToggleCamera$: Observable<boolean>;
    private _mediaTypes;
    private _mediaConstraints;
    private _updateMedia;
    private _videoStream?;
    private _audioOnlyStream?;
    private _audioMuted;
    private _videoMuted;
    private _beforeShareScreenVideo;
    private devices$;
    private activeAudioInputDevice;
    private activeVideoInputDevice;
    private forceRefreshDevices;
    private subscription;
    /** @ignore */
    constructor(mediaConstraints: MediaStreamConstraints, updateMedia: UpdateMedia);
    uninit(): void;
    /**
     * Return the media types configured for the call
     */
    getMediaTypes(): MediaTypes;
    /**
     * Update the enabled local media. This feature is only available
     * when the call has already been connected if "media-update" capability is present.
     * @param mediaTypes The requested media
     *
     * @example <caption>Disable video</caption>
     * await call.setMediaTypes({audio: true, video: false, screen: false});
     * console.log("media updated");
     */
    setMediaTypes(mediaTypes: MediaTypes): Promise<void>;
    /**
     * Return the media constraints configured for the call
     */
    getMediaConstraints(): MediaStreamConstraints;
    /**
     * Update constraints of local media. This feature is only available when the call
     * has already been connected if "media-update" capability is present.
     * @param mediaConstraints The requested media constraints
     *
     * @example <caption>Change video resolution</caption>
     * const audio = true;
     * const video = {
     *   height: 256,
     *   width: 256,
     * };
     * await call.setMediaConstraints({audio, video});
     * console.log("media updated");
     */
    setMediaConstraints(mediaConstraints: MediaStreamConstraints): Promise<void>;
    /**
     * Obtains current enabled media stream constraints.
     * This is a combination of the media stream constraints configured
     * for the call and the current media types.
     */
    getCurrentMediaConstraints({ mediaTypes, mediaConstraints, }?: {
        mediaTypes?: MediaTypes | undefined;
        mediaConstraints?: MediaStreamConstraints | undefined;
    }): MediaStreamConstraints;
    /**
     * Returns the local video stream
     */
    getVideoStream(): ManagedStream | undefined;
    /** @ignore */
    setVideoStream(stream?: MediaStream): void;
    /** @ignore */
    setAudioOnlyStream(stream?: MediaStream): void;
    /**
     * Returns a boolean value indicating if the call has a local audio track
     */
    hasAudioTrack(): boolean;
    /**
     * Returns a boolean value indicating if the call has a local video track
     */
    hasVideoTrack(): boolean;
    /**
     * Returns a boolean value indicating if local audio is muted
     */
    isAudioMuted(): boolean;
    /**
     * Mutes or unmutes the audio. If no parameter is specified it toggles current value.
     * @param mute If specified forces audio to be mute or unmute
     */
    muteAudio(mute?: boolean): void;
    /**
     * Returns a boolean value indication if local video is muted
     */
    isVideoMuted(): boolean;
    /**
     * Mutes or unmutes the video. If no parameter is specified it toggles current value.
     *
     * Note that this method just turns the emitted video black and implies no media renegotiation.
     * Therefore, a video track will continue to be streamed. If you are instead looking for a method
     * to stop sending video altogether check {@link LocalMediaHandler.toggleVideo}.
     * @param mute When specified forces video to be mute or unmute
     */
    muteVideo(mute?: boolean): void;
    /**
     * Enables or disables the video. If no parameter is specified it toggles current value.
     *
     * Note that this method will imply a media renegotation because the video track will be
     * added or removed from the RTCPeerConnection. As a consequence, remote participants
     * will receive a change in their remote participants streams.
     * @param video If specified forces video to be enabled or not
     */
    toggleVideo(video?: boolean): Promise<void>;
    /**
     * Shares the screen. This feature is only available if "screen-sharing" capability is present.
     * @param screen send screen if true, camera if false. If not specified it toggles from the last state.
     */
    toggleScreen(screen?: boolean): Promise<void>;
    /**
     * Updates media types adding video when screen is false or adds an internal mark to know video must be
     * enabled when screen sharing ends.
     */
    addVideo(): Promise<void>;
    /**
     * Updates the audio input device in used to the specified one
     * @param audioInputDevice If no value is specified the default one is selected
     */
    setActiveAudioInputDevice(audioInputDevice?: MediaDeviceInfo): Promise<void>;
    /**
     * Updates the video input device in used to the specified one
     * @param videoInputDevice If no value is specified the default one is selected
     */
    setActiveVideoInputDevice(videoInputDevice?: MediaDeviceInfo): Promise<void>;
    /**
     * Changes the local video stream to the next available camera.
     */
    toggleCamera(): Promise<void>;
    /**
     * Force the update of the devices list
     */
    forceUpdateDevices(): Promise<void>;
    private getActiveVideoInputDeviceFromLocalStreams;
    private getNextVideoInputDevice;
}
export {};
