import { StreamRecorder } from './StreamRecorder';
/**
 * This class provides access to media control functions during a call
 * This class must never be directly instantiated
 */
export declare class ManagedStream {
    private id;
    private mediaStream;
    private local;
    /** @ignore */
    constructor(mediaStream: MediaStream, local?: boolean);
    /**
     * The id of this stream
     */
    getId(): string;
    /**
     * Indicates if this managed stream is local. This means that its sources are
     * local devices of this machine and that it was obtained of a getUserMedia call
     * and not from a RTCPeerConnection
     */
    isLocal(): boolean;
    /**
     * Indicates if this managed stream is remote. This means that its sources are not
     * local devices of this machine and that it was obtained from a RTCPeerConnection
     * and not from a getUserMedia call
     */
    isRemote(): boolean;
    /**
     * Provides access to the underlying WebRTC MediaStream object
     */
    getMediaStream(): MediaStream;
    /**
     * Provides access to all the tracks of the managed stream
     */
    getTracks(): MediaStreamTrack[];
    /**
     * Provides access to the audio tracks of the managed stream
     */
    getAudioTracks(): MediaStreamTrack[];
    /**
     * Provides access to the video tracks of the managed stream
     */
    getVideoTracks(): MediaStreamTrack[];
    /**
     * Provides access to the video tracks that are not a screen of the managed stream
     * @deprecated This method relies in browser implementation details and must not be used
     */
    getCameraTracks(): MediaStreamTrack[];
    /**
     * Provides access to the screen tracks of the managed stream
     * @deprecated This method relies in browser implementation details and must not be used
     */
    getScreenTracks(): MediaStreamTrack[];
    /**
     * Allows to know if the managed stream has audio tracks
     * @return A boolean value indicating if the managed stream has at least one audio track
     */
    hasAudioTracks(): boolean;
    /**
     * Allows to know if the managed stream has video tracks
     * @return A boolean value indicating if the managed stream has at least one video track
     */
    hasVideoTracks(): boolean;
    /**
     * Allows to know if the managed stream has camera tracks
     * @deprecated This method relies in browser implementation details and must not be used
     * @return A boolean value indicating if the managed stream has at least one camera track
     */
    hasCameraTracks(): boolean;
    /**
     * Allows to know if the managed stream has screen tracks
     * @deprecated This method relies in browser implementation details and must not be used
     * @return A boolean value indicating if the managed stream has at least one screen track
     */
    hasScreenTracks(): boolean;
    /**
     * Stops every track of the underlying MediaStream
     */
    stop(): void;
    /**
     * Indicates if every audio track is muted
     */
    isAudioMuted(): boolean;
    /**
     * Indicates if every video track is muted
     */
    isVideoMuted(): boolean;
    /**
     * Indicates if every screen track is muted
     * @deprecated This method relies in browser implementation details and must not be used
     */
    isScreenMuted(): boolean;
    /**
     * Mutes or unmutes audio tracks of this stream
     * @param mute If true disables audio tracks, if false enables them
     * If not argument is provided it toggles the mute state on audio tracks
     */
    muteAudio(mute?: boolean): void;
    /**
     * Mutes or unmutes video tracks of this stream
     * @param mute If true disables video tracks, if false enables them
     * If not argument is provided it toggles the mute state on video tracks
     */
    muteVideo(mute?: boolean): void;
    /**
     * Mutes or unmutes screen tracks of this stream
     * @deprecated This method relies in browser implementation details and must not be used
     * @param mute If true disables screen tracks, if false enables them
     * If not argument is provided it toggles the mute state on screen tracks
     */
    muteScreen(mute?: boolean): void;
    /**
     * Allows taking captures of the video tracks of this stream
     * @return A promise containing an array of Blobs with a capture
     * of the video. One Blob for each video track of this stream
     */
    takePhotos(): Promise<Blob[]>;
    /**
     * Creates a StreamRecorder object that will allow recording the stream
     */
    createStreamRecorder(): StreamRecorder;
}
