import { JanusRoom } from '@quobis/wrapper-stack';
import { ConferenceMediaStream } from '@quobis/wrapper-stack/lib/conference-media/ConferenceMediaStream';
import { EventEmitter2 } from 'eventemitter2';
/**
 * Updated conference event.
 * Fired when a conference where user participates is updated.
 * @event UPDATED_CONFERENCE_EVENT
 * @type {object}
 */
export declare const UPDATED_CONFERENCE_EVENT = "conference-updated";
/**
 * Destroyed conference event.
 * Fired when user leaves a conference.
 * @event DESTROYED_CONFERENCE_EVENT
 * @type {object}
 */
export declare const DESTROYED_CONFERENCE_EVENT = "conference-destroyed";
/**
 * Expel conference event.
 * Fired when conference is detroyed by other user.
 * @event EXPEL_CONFERENCE_EVENT
 * @type {object}
 */
export declare const EXPEL_CONFERENCE_EVENT = "expelled";
/**
 * Local streams changed event.
 * Fired when local streams changes.
 * @event LOCAL_STREAM_CHANGED
 * @type {object}
 * @property {Array<MediaStream>} streams current local streams.
 */
export declare const LOCAL_STREAM_CHANGED = "localStreamChanged";
/**
 * New local stream event.
 * Fired when a new local stream arrives
 * @event LOCAL_STREAM_ADDED
 * @type {object}
 * @property {string} participant gatewayUsername of the local stream
 * @property {MediaStream} stream new local stream
 */
export declare const LOCAL_STREAM_ADDED = "localStreamAdded";
/**
 * Local stream gone event
 * Fired when a local stream stops being available
 * @event LOCAL_STREAM_REMOVED
 * @type {object}
 * @property {string} participant gatewayUsername of the local stream
 * @property {MediaStream} stream removed local stream
 */
export declare const LOCAL_STREAM_REMOVED = "localStreamRemoved";
/**
 * Remote streams changes event.
 * Fired when streams associated with a remote peer changes.
 * @event REMOTE_STREAM_CHANGED
 * @type {object}
 * @property {string} participant user name of remote peer.
 * @property {Array<MediaStream>} streams current local streams.
 */
export declare const REMOTE_STREAM_CHANGED = "remoteStreamChanged";
/**
 * Remote streams added event
 * Fired when a new remote stream arrives
 * @event REMOTE_STREAM_ADDED
 * @type {object}
 * @property {string} participant user name of remote peer.
 * @property {MediaStream} streams new remote stream
 * @property {string} [reason='NEW'|'UNHOLD'] reason of stream addition
 */
export declare const REMOTE_STREAM_ADDED = "remoteStreamAdded";
/**
 * Remote streams remove event
 * Fired when a new remote stops being available
 * @event REMOTE_STREAM_REMOVED
 * @type {object}
 * @property {string} participant user name of remote peer.
 * @property {MediaStream} streams removed stream
 * @property {string} [reason='GONE'|'HOLD'] reason of stream removal
 */
export declare const REMOTE_STREAM_REMOVED = "remoteStreamRemoved";
/**
 * Fired when the user has to invite to other participant
 * to implement an unattended call transfer
 * @event TRANSFERING_CALL
 * @type {object}
 * @property {string} to username to send an invitation to
 * @property {string} callTransferID identifier of
 * an unattended call transfer.
 * @property {string} roomId identifier of a room
 * @property {string} mediatypes identifier of a room
 */
export declare const TRANSFERING_CALL = "transferingCall";
declare type Dtmf = '*' | '#' | '1' | '2' | '3' | '4' | '5' | '6' | '7' | '8' | '9';
declare type Session = any;
declare type JanusRoom = any;
interface MediaTypes {
    audio: boolean;
    video: boolean;
    screen: boolean;
}
interface Invite {
    id: string;
    from: string;
    mediatypes: MediaTypes;
    context: Record<string, string>;
}
interface Dependencies {
    session?: Session;
    WebSocket?: typeof WebSocket;
    room?: JanusRoom;
}
/**
 * @fires UPDATED_CONFERENCE_EVENT
 * @fires DESTROYED_CONFERENCE_EVENT
 * @fires EXPEL_CONFERENCE_EVENT
 * @fires LOCAL_STREAM_CHANGED
 * @fires REMOTE_STREAM_CHANGED
 * @fires TRANSFERING_CALL
 * @extends EventEmitter2
 */
export declare class Conference extends EventEmitter2 {
    private dependencies;
    /**
     * Server client
     */
    private _session;
    /**
     * Janus client
     */
    private _room;
    /**
     * Room identifier
     */
    private _id;
    /**
     * Invitation when user doesn't joined the conference.
     */
    private _invite;
    /**
     * User identifiers that participate on a conference.
     */
    private _participants;
    /**
     * Indicates if conference is being recorded
     */
    private _record;
    /**
     * Conference server
     */
    private _server;
    /**
     * Conference access token
     */
    private _token;
    /**
     * Conference ice servers
     */
    private _ice;
    /**
     * Contains a list of pending invitations (still not accepted/rejected
     * by remote peer) transaction identifiers. Used to cancel a previous invitation
     * and determine if an user has been invited.
     */
    private _pendingInvites;
    /**
     * True if leave method was called
     */
    private _left;
    private parallelSipExtension;
    private sipUri;
    private _uninitializingRoom;
    private _mediaUpdateInProgress;
    private transferingCall;
    constructor(dependencies?: Dependencies);
    /**
     * Conference identifier
     */
    get id(): string;
    /**
     * Indicate if invited
     */
    get invited(): boolean;
    /**
     * Returns an object with the invitation (with the properties "id" an "from")
     * Needed to know who is inviting us in anonymous rooms
     */
    get invite(): Invite | null;
    /**
     * Indicate if joined
     */
    get joined(): boolean;
    /**
     * Server session.
     */
    set session(session: Session);
    /**
     * Conference participants, expressed as a list of current user identifiers
     */
    get participants(): string[];
    /**
     * Current local streams.
     */
    get localStreams(): ConferenceMediaStream[];
    /**
     * Current remote streams.
     */
    get remoteStreams(): ConferenceMediaStream[];
    /**
     * Current conference streams.
     */
    get streams(): ConferenceMediaStream[];
    /**
     * Local hold
     * Stop publishing and subscribing to the media in the conference
     */
    hold(): Promise<void>;
    /**
     * Stop local hold
     * Republishes all previously published media, subscribes to previously subscribed
     * media and notifies new status to other participants.
     */
    unhold(): Promise<void>;
    /**
     * Check if conference is on hold state.
     */
    get isOnHold(): boolean;
    /**
     * Suspend conference:
     *  - cancel any pending invitation sent.
     *  - decline invitation if we was invited to this conference.
     */
    suspend(): Promise<void>;
    /**
     * Resume conference
     */
    resume(): Promise<void>;
    /**
     * Join this conference and start sending local media defined by mediatype parameter.
     * @param mediatypes local media used after joining the conference.
     */
    join(mediatypes: MediaTypes): Promise<void>;
    /**
     * Add participant to this conference.
     * @throws {Error} if participant is already present on conference or a pending
     * invitation exists.
     * @param participant user name to add.
     * @param mediatypes the mediatypes requested to the new participant.
     * @param requestId the ID of the request that generated this invitation.
     * @param context arbitrary context that can be sent to invites
     * @return resolved with a boolean value that indicates if remote accepts the invitation.
     */
    inviteParticipant(participant: string, mediatypes: MediaTypes, requestId?: string, context?: Record<string, string>): Promise<{
        code: number;
        whoAccepted?: string;
    }>;
    /**
     * Invite participants to this conference.
     * @throws {Error} if participant is already present on conference or a pending invitation exists.
     * @param participants participants that will be invited.
     * @param mediaTypes the mediatypes requested to the new participant.
     * @param [context] arbitrary context that can be sent to invites
     * @returns {Promise<Object[]>} A promise with an array of objects with two properties: SIP code and whoAccepted the invite
     * @property {number} code SIP code of the response
     * @property {string} whoAccepted User id of the participant that accepted the invite
     */
    inviteMany(participants: Array<{
        to: string;
        inviteId: string;
    }>, mediaTypes: MediaTypes, context: Record<string, string>): Promise<Array<{
        code: number;
        whoAccepted?: string;
    }>>;
    /**
     * Cancel an invite
     * @param participant user name to decline.
     */
    cancelInvitation(participant: string): void;
    cancelPendingInvite(participant: string): void;
    /**
     * Removes a participant from this conference.
     * @param participant user name to remove.
     * @return resolved when remote user leaves conference.
     */
    expelParticipant(participant: string): Promise<void>;
    /**
     * Leaves this conference or rejects a previous invitation.
     * @param errorCode the rejection cause when an invitation is received
     * and the conference has not been joined.
     * @throws {Error} when already joined or a previous invitation was not received.
     * @return resolved on success with self reference.
     */
    leave(errorCode: number): Promise<Conference>;
    /**
     * Deinitialize Janus client after leaving a conference.
     * @return {Promise} resolved on success
     */
    private uninitRoom;
    private uninitRoomIfExists;
    /**
     * Update local media types.
     * @param mediatypes required mediatypes.
     */
    update(mediatypes: MediaTypes): Promise<void>;
    /**
     * True if conference is being recorded
     */
    get recording(): boolean;
    /**
     * Starts recording this conference
     */
    startRecording(): Promise<Conference>;
    /**
     * Stops conference recording
     */
    stopRecording(): Promise<Conference>;
    /**
     * Create an unattended call transfer towards a user in the system
     * @param participant user name to call.
     * @param mediatypes the mediatypes requested to the new participant.
     */
    unattendedCallTransfer(participant: string, mediatypes: MediaTypes): Promise<void>;
    /**
     * Accept inviting to other participant to make an unattended call transfer
     * @param {string} callTransferID identifier of a call transfer
     */
    acceptCallTransfer(callTransferID: string): Promise<void>;
    createJanusRoom(): JanusRoom;
    sendDtmf(value: Dtmf): unknown;
    getParticipants(): unknown;
    /**
     * Initialize Janus client after joining a conference.
     */
    private initRoom;
    private removeRoomListeners;
    /**
     * Updates instance properties with data returned by a signaling server
     * @param {object} data server data
     */
    updateWithServerData(data: any): Conference;
    /**
     * Callback called when a destroyed room event is received.
     */
    private onRoomDestroyed;
    /**
     * Callback called when a room update event is received.
     */
    private onRoomUpdated;
    /**
     * Callback called when an invitation is canceled
     */
    private onInviteCancel;
    /**
     * Callback called when a ConferenceMediaStream is added.
     */
    private onStreamAdded;
    /**
     * Callback called when a ConferenceMediaStream is removed.
     */
    private onStreamRemoved;
    /**
     * Callback called when a ConferenceMediaStream has changed.
     */
    private onStreamChanged;
    /**
     * Callback called when an invitation is canceled
     */
    private onTransferingCallToPeer;
    /**
     * Callback called when a new participant joins the room
     */
    private onParticipantAdded;
    /**
     * Callaback called when a participant leaves the room
     */
    private onParticipantRemoved;
    /**
     * Callback called when a remote participant does a hold
     */
    private onParticipantHold;
    /**
     * Callback called when a remote participant stops a hold
     */
    private onParticipantUnhold;
    /**
     * Callback called when change the participants who are speaking
     */
    private onSpeakerChanged;
}
export {};
